####======================================
### Project: A Comparison of Monoscopic and Stereoscopic 3D Visualizations: Effect on Spatial Planning
### Script to analyze the measures obtained from the .csv data file
### Data analysis and visualization
### Dajana Snopkova, Masaryk University, snopkova.dajana@mail.muni.cz, 2021
###======================================


setwd("C:/Users/Dajan/Documents/123_SKOLA/PHD/Vysilace clanek")
library(readr)
df <- read_delim("data_raw.txt", "\t", escape_double = FALSE, trim_ws = TRUE)

# ------ Descriptive stats - mouse clicks example
library(effsize)
library(rcompanion)

pseudo <- (split(df$mouse_clicks, df$condition)$pseudo)
real <- (split(df$mouse_clicks, df$condition)$real)
summary(pseudo)
summary(real)
sd(pseudo)
sd(real)
shapiro.test(pseudo)
shapiro.test(real)
# non-normal distributions
wilcox.test(pseudo,real)
wilcoxonR(x = df$mouse_clicks, g = df$condition, ci = TRUE)
# normal distributions
t.test(pseudo,real)
cohen.d(pseudo, real, hedges.correction = TRUE)

# ------- Graphs
library(ggplot2)
library(ggpubr)

boxplot_corr <- ggplot(df, aes(x=condition, y=correct_rate)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0.6,1), breaks = seq(0,1,0.1), expand = c(0,0), labels = scales::percent) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Effectiveness \n(Correctness Rate) [%]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_time <- ggplot(df, aes(x=condition, y=task_time)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,1500), breaks = seq(0,1500,250), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Efficiency \n(Task Time) [s]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_tbeff <- ggplot(df, aes(x=condition, y=time_based_effic)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,0.1), breaks = seq(0,0.1,0.02), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Time-based Efficiency \n[goals/s]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_ovreleff <- ggplot(df, aes(x=condition, y=overal_rel_effic)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0.6,1), breaks = seq(0,1,0.1), expand = c(0,0), labels = scales::percent) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Overall Relative Efficiency \n[%]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

eff_all <- ggarrange(boxplot_corr, boxplot_time, boxplot_tbeff, boxplot_ovreleff, ncol = 2, nrow = 2,
                     common.legend = TRUE, legend = "none", align = "v")

ggsave(file="eff_all.svg", plot=eff_all, width=6, height=5)

boxplot_mousecl <- ggplot(df, aes(x=condition, y=mouse_clicks)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,1000), breaks = seq(0,1000,200), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +  
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Sum of Mouse Clicks \n[n]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_alllen <- ggplot(df, aes(x=condition, y=all_len_sum)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,900), breaks = seq(0,900,100), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Length of Virtual \nTtrajectory [km]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_3drot <- ggplot(df, aes(x=condition, y=rotation_3D)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,10000), breaks = seq(0,10000,1000), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  ggtitle("Total 3D Rotation \n[°]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_mousecl_r <- ggplot(df, aes(x=condition, y=rel_mouse_clicks)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,1), breaks = seq(0,1,0.2), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  #stat_compare_means() +
  ggtitle("Mouse Clicks \nper Second [n/s]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_alllen_r <- ggplot(df, aes(x=condition, y=averge_speed)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,1.5), breaks = seq(0,1.5,0.25), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  #stat_compare_means() +
  ggtitle("Average Speed \n[km/s]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

boxplot_3drot_r <- ggplot(df, aes(x=condition, y=average_rotation)) +
  geom_violin(fill= "white", lwd = 0.8, trim=TRUE, color="grey") +
  stat_boxplot(geom = "errorbar", width = 0.2) + 
  geom_boxplot(width = 0.6, color="black",outlier.size=1, fill = "#A4A4A4")+
  stat_summary(fun.y=mean, geom="point", shape=1, size=3) +
  scale_y_continuous(limits = c(0,14), breaks = seq(0,14,2), expand = c(0,0), labels=function(x) format(x, big.mark = ",", scientific = FALSE)) +
  scale_x_discrete(labels=c("Pseudo 3D", "Real 3D")) +
  #stat_compare_means() +
  ggtitle("Average 3D \nAngular Velocity [°/s]") + 
  theme_classic() +
  theme(legend.position="top", plot.title = element_text(hjust = 0.5, face="bold", size=11), axis.title = element_blank())

interaction_all <- ggarrange(boxplot_mousecl, boxplot_alllen, boxplot_3drot, boxplot_mousecl_r, boxplot_alllen_r, boxplot_3drot_r, ncol = 3, nrow = 2,
                             common.legend = TRUE, legend = "none", align = "v")

ggsave(file="interaction_all.svg", plot=interaction_all, width=7, height=4)
